@@ -19,15 +19,16 @@
 var gettext;
 var ngettext;
 
-// Create a simple gettext function which uses the MwbIGettext service
+// Create a simple gettext function which uses the gettext wrappers in
+// MwbIPagesService
 (function() {
   // Using an anonymous function to create a static gettext service variable
-  var gettextService = (Components.classes["@moblin.org/mwb-gettext-service;1"]
-                        .getService(Components.interfaces.MwbIGettext));
-  gettext = function(str) { return gettextService.gettext(str); }
+  var pagesService = (Components.classes["@moblin.org/mwb-pages-service;1"]
+                      .getService(Components.interfaces.MwbIPagesService));
+  gettext = function(str) { return pagesService.gettext(str); }
   ngettext = function(singular, plural, count)
   {
-    return gettextService.ngettext(singular, plural, count);
+    return pagesService.ngettext(singular, plural, count);
   }
 })();
 
