@@ -42,6 +42,11 @@ private:
   static MwbFaviconLoader *favicon_loader;
 
   MhsHistory *history;
+
+  gchar *default_favicon;
+  gsize default_favicon_length;
+
+  friend class MwbFaviconClosure;
 };
 
 #endif /* _MWB_FAVICON_LOADER_H */
